'''
Created on Jan 12, 2013

@author: dirk dierickx
'''


'''A package for removing wiki markup text'''


def from_string(string=''):
    '''
    Remove wiki markup text from a string
    '''
    from dewiki.parser import Parser
    return Parser().parse_string(string)


def from_byte(byte=None):
    pass


def from_file(file=None):
    pass



'''
Created on Jan 12, 2013

@author: dirk dierickx
'''
import re


class Parser(object):
    '''
    Parser to remove all kinds of wiki markup tags from an object
    '''

    def __init__(self):
        '''
        Constructor
        '''
        self.string = ''
        # all the following regex remove all tags that cannot be rendered
        # in text
        self.wiki_re = re.compile(r"""\[{2}(File|Category):[\s\S]+\]{2}|
                                        [\s\w#()]+\||
                                        (\[{2}|\]{2})|
                                        \'{2,5}|
                                        (<s>|<!--)[\s\S]+(</s>|-->)|
                                        {{[\s\S]+}}|
                                        ^={1,6}|={1,6}$""", re.X)

    def __list(self, listmatch):
        return ' ' * (len(listmatch.group()) - 1) + '*'

    def __parse(self, string=''):
        '''
        Parse a string to remove and replace all wiki markup tags
        '''
        self.string = string
        self.string = self.wiki_re.sub('', self.string)
        # search for lists
        self.listmatch = re.search('^(\*+)', self.string)
        if self.listmatch:
            self.string = self.__list(self.listmatch) + re.sub('^(\*+)', \
                          '', self.string)
        return self.string

    def parse_string(self, string=''):
        '''
        Parse a string object to de-wikified text
        '''
        self.strings = string.splitlines(1)
        self.strings = [self.__parse(line) for line in self.strings]
        return ''.join(self.strings)

    def parse_byte(self, byte=None):
        '''
        Parse a byte object to de-wikified text
        '''
        pass

    def parse_file(self, file=None):
        '''
        Parse the content of a file to de-wikified text
        '''
        pass



import os
from setuptools import setup, find_packages

version = '0.1.0'
readme = os.path.join(os.path.dirname(__file__), 'README.md')
long_desc = open(readme).read() + '\n\n'

setup(name = 'dewiki',
      version = version,
      description = 'Python module to remove wiki markup',
      long_description = long_desc,
      classifiers = [
                     "Programming Language :: Python",
                     ("Topic :: Software Development :: Libraries :: Python Modules"),
                     ],
      keywords = "wiki",
      author = "Dirk Dierickx",
      author_email = 'dirk.dierickx@gmail.com',
      url = 'https://github.com/daddyd/dewiki',
      license = 'GPL',
      packages = find_packages()
      )
